Package: NormalLaplace
Version: 0.3-2
Date: 2025-03-28
Title: The Normal Laplace Distribution
Authors@R: c(person(given = "David",
                    family = "Scott",
                    role = c("aut", "cre"),
                    email = "d.scott@auckland.ac.nz"),
             person(given = c("Jason", "Shicong"),
                    family = "Fu",
                    role = "aut"),
             person(given = "Simon",
                    family = "Potter",
                    role = "aut"))
Maintainer: David Scott <d.scott@auckland.ac.nz>
Depends: R (>= 3.0.1)
Imports: grDevices, graphics, stats, DistributionUtils,
        GeneralizedHyperbolic
Suggests: RUnit
Encoding: UTF-8
Description: Functions for the normal Laplace distribution.  Currently, it
 provides limited functionality.  Density, distribution and quantile
 functions, random number generation, and moments are provided.
License: GPL (>= 2)
URL: https://r-forge.r-project.org/projects/rmetrics/
NeedsCompilation: no
Packaged: 2025-03-28 09:41:56 UTC; dsco0
Author: David Scott [aut, cre],
  Jason Shicong Fu [aut],
  Simon Potter [aut]
Repository: CRAN
Date/Publication: 2025-03-28 10:10:03 UTC
Built: R 4.6.0; ; 2026-04-27 11:20:29 UTC; unix
