################################################
### Imports
################################################
importFrom("grDevices", "dev.interactive")
importFrom("graphics", "abline", "curve", "hist", "hist.default",
           "par", "plot", "title")
importFrom("stats", "dnorm", "na.omit", "nlm", "nlminb", "optim",
           "pnorm", "ppoints", "rnorm", "splinefun", "uniroot", "var")

exportPattern("nl")
export(millsR)

importFrom("grDevices", dev.interactive)

importFrom("graphics", abline, curve, hist, hist.default, par, plot, title)

importFrom("stats", dnorm, na.omit, nlm, nlminb, optim,
           pnorm, ppoints, rnorm, splinefun, uniroot, var)

importFrom("DistributionUtils",
           besselRatio, is.wholenumber,
           logHist,
           momIntegrated, momChangeAbout, safeIntegrate,
           skewness, kurtosis,
           tsHessian)

importFrom("GeneralizedHyperbolic", rskewlap)

## ------------- Exports ---------------------------------------

exportPattern("nl") ## "Pattern" FIXME: rather not the S3 methods below
export(millsR)



################################################
## S3 classes
################################################
S3method(print,nlFit)
S3method(plot,nlFit)
S3method(coef,nlFit)
S3method(vcov,nlFit)
S3method(summary,nlFit)
S3method(print,summary.nlFit)

################################################
## Functions
################################################
exportPattern("nl")
export(millsR)
